@@ -1,10 +1,13 @@
 from pytest import raises
 import sqlalchemy as sa
-from sqlalchemy_i18n import Translatable, configure_translatables
+from sqlalchemy_i18n import Translatable, make_translatable
 from wtforms_alchemy import ModelForm
 from tests import ModelFormTestCase, MultiDict
 
 
+make_translatable()
+
+
 class TestInternationalizationExtension(ModelFormTestCase):
     def init(self):
         class ModelTest(self.base, Translatable):
@@ -23,9 +26,6 @@ class TestInternationalizationExtension(ModelFormTestCase):
             def get_locale(self):
                 return 'en'
 
-        sa.event.listen(
-            sa.orm.mapper, 'after_configured', configure_translatables
-        )
         self.ModelTest = ModelTest
         sa.orm.configure_mappers()
         Session = sa.orm.sessionmaker(bind=self.engine)
