@@ -1,4 +1,4 @@
-from pytest import raises
+from pytest import raises, mark
 import sqlalchemy as sa
 from wtforms.fields import (
     TextField,
@@ -13,6 +13,7 @@ from sqlalchemy_utils import (
     NumberRangeType,
     EmailType
 )
+from sqlalchemy_utils.types import phone_number
 from wtforms_components import (
     ColorField,
     DateField,
@@ -33,20 +34,38 @@ from wtforms_components import PhoneNumberField
 from tests import ModelFormTestCase
 
 
-class CustomType(sa.types.TypeDecorator):
+class UnknownType(sa.types.UserDefinedType):
+
+    def get_col_spec(self):
+        return "UNKNOWN()"
+
+
+class CustomUnicodeTextType(sa.types.TypeDecorator):
     impl = sa.types.UnicodeText
 
 
+class CustomUnicodeType(sa.types.TypeDecorator):
+    impl = sa.types.Unicode
+
+
+class CustomNumericType(sa.types.TypeDecorator):
+    impl = sa.types.Numeric
+
+
 class TestModelColumnToFormFieldTypeConversion(ModelFormTestCase):
     def test_raises_exception_for_unknown_type(self):
         with raises(UnknownTypeException):
-            self.init(type_=CustomType)
+            self.init(type_=UnknownType)
             self.form_class()
 
     def test_unicode_converts_to_text_field(self):
         self.init()
         self.assert_type('test_column', TextField)
 
+    def test_custom_unicode_converts_to_text_field(self):
+        self.init(type_=CustomUnicodeType)
+        self.assert_type('test_column', TextField)
+
     def test_string_converts_to_text_field(self):
         self.init(type_=sa.String)
         self.assert_type('test_column', TextField)
@@ -59,6 +78,10 @@ class TestModelColumnToFormFieldTypeConversion(ModelFormTestCase):
         self.init(type_=sa.UnicodeText)
         self.assert_type('test_column', TextAreaField)
 
+    def test_custom_unicode_text_converts_to_text_area_field(self):
+        self.init(type_=CustomUnicodeTextType)
+        self.assert_type('test_column', TextAreaField)
+
     def test_boolean_converts_to_boolean_field(self):
         self.init(type_=sa.Boolean)
         self.assert_type('test_column', BooleanField)
@@ -79,6 +102,10 @@ class TestModelColumnToFormFieldTypeConversion(ModelFormTestCase):
         self.init(type_=sa.Numeric)
         self.assert_type('test_column', DecimalField)
 
+    def test_custom_numeric_converts_to_decimal_field(self):
+        self.init(type_=CustomNumericType)
+        self.assert_type('test_column', DecimalField)
+
     def test_enum_field_converts_to_select_field(self):
         choices = ['1', '2']
         self.init(type_=sa.Enum(*choices))
@@ -130,15 +157,18 @@ class TestModelColumnToFormFieldTypeConversion(ModelFormTestCase):
         self.init(type_=sa.types.REAL)
         self.assert_type('test_column', FloatField)
 
+    @mark.xfail('phone_number.phonenumbers is None')
     def test_phone_number_converts_to_phone_number_field(self):
         self.init(type_=PhoneNumberType)
         self.assert_type('test_column', PhoneNumberField)
 
+    @mark.xfail('phone_number.phonenumbers is None')
     def test_phone_number_country_code_passed_to_field(self):
         self.init(type_=PhoneNumberType(country_code='SE'))
         form = self.form_class()
         assert form.test_column.country_code == 'SE'
 
+    @mark.xfail('phone_number.phonenumbers is None')
     def test_phone_number_type_has_no_length_validation(self):
         self.init(type_=PhoneNumberType(country_code='FI'))
         field = self._get_field('test_column')
